package be.ac.ua.broker.allocation;

/**
 * This class is used to represent the different options used during the
 * resource allocation phase of the broker: only using on-demand instances is
 * the first option, no spot instances is another option, spot-enabled (which
 * uses the spot model to determine the bid) and spot-optimal (which used the
 * actual spot price history to determine the bid).
 * 
 * @author Vermeersch Kurt
 * @date May 2011
 */
public class AllocatorOptions {

	/** Allocation Scheme Option: use only on-demand instances. */
	public static final String ALLONDEMAND = "onlyondemand";

	/** Allocation Scheme Option: use only on-demand and reserved instances. */
	public static final String NOSPOT = "reserved";

	/**
	 * Allocation Scheme Option: use all three pricing models, use the spot
	 * model to determine the bid price.
	 */
	public static final String SPOT = "spotenabled";

	/**
	 * Allocation Scheme Option: use all three pricing models, use the actual
	 * spot price history to determine the optimal bid price.
	 */
	public static final String SPOTOPTIMAL = "optimalspot";
}