package be.ac.ua.broker.allocation.spot.model;

import java.io.FileNotFoundException;
import java.io.IOException;

import be.ac.ua.broker.utils.DateUtility;

import com.csvreader.CsvReader;

/**
 * The DataReader class is used to read data from the input CSV data file.
 * 
 * @author Vermeersch Kurt (Based on Sangho Yi c++ implementation of the spot
 *         model)
 * @date October 2010
 */
public class DataReader {

	/** State used for the simulation */
	private State state;

	/**
	 * Constructor for DataReader
	 * 
	 * @param st
	 *            the state object being used during the simulation
	 */
	public DataReader(State st) {
		state = st;
	}

	/**
	 * Read data from the data input file and put it in the source records in
	 * the state object of the simulation
	 */
	public void readSourceData() {
		try {
			SrcRecord r = state.getSourceRecord();
			CsvReader reader = new CsvReader(r.getFileName());
			String prevDate = null;
			String prevPrice = null;
			reader.readHeaders();
			if (reader.readRecord()) {
				prevDate = reader.get(0);
				prevPrice = reader.get(1);
			}
			int i = 0;
			while (reader.readRecord()) {
				String date = reader.get(0);
				String price = reader.get(1);
				int numberOfMinutes = DateUtility.getNumberOfMinutesBetween(
						DateUtility.toDate(prevDate), DateUtility.toDate(date));
				for (int j = 0; j < numberOfMinutes; j++) {
					r.setData(i, Double.parseDouble(prevPrice));
					i++;
					if (i == SpotModelOptions.MAX_RECORD) {
						break;
					}
				}
				prevDate = date;
				prevPrice = price;
				if (i == SpotModelOptions.MAX_RECORD) {
					break;
				}
			}
			reader.close();
			// Set r.n_record as the last value of i
			r.setRecord(i);
			r.determineLowestAndHighest();
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}

	}
}
