package be.ac.ua.broker.allocation.spot.model;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import com.csvreader.CsvReader;

/**
 * The OutputReader class is used to read data from the output files generated
 * by the spot model.
 * 
 * @author Vermeersch Kurt (Based on Sangho Yi c++ implementation of the spot
 *         model)
 * @date October 2010
 */
public class OutputReader {

	/** CsvReader instance */
	private CsvReader fReader;

	/**
	 * Get the bid to use in the broker application for the given instance type,
	 * 
	 * @param inputFile
	 *            the spot model output file to get the bid information from
	 * @param inst
	 *            the instance type to get bid information for
	 * @param t
	 *            the length of the task
	 * @param et
	 *            the desired estimated time
	 * @return the appropriate bid information
	 * @throws Exception
	 *             if the file is not found.
	 */
	public double getBid(final String inputFile, String inst, int t, int et,
			String checkpointingScheme, double confindenceLevel)
			throws Exception {
		List<Double> possibilities = new ArrayList<Double>();
		try {
			fReader = new CsvReader(inputFile);
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		}
		try {
			if (fReader != null) {
				while (fReader.readRecord()) {
					int cols = fReader.getColumnCount();
					if (cols >= 4
							&& fReader.get(0).equalsIgnoreCase(inst)
							&& fReader.get(2).equals(checkpointingScheme)
							&& Double.parseDouble(fReader.get(3)) == t
							&& Double.parseDouble(fReader.get(5)) < et
							&& Double.parseDouble(fReader.get(4)) == confindenceLevel
							&& Double.parseDouble(fReader.get(7)) < Double
									.parseDouble(fReader.get(1))) {
						possibilities.add(Double.parseDouble(fReader.get(1)));
					}
				}
				fReader.close();
			}
		} catch (IOException e) {
			e.printStackTrace();
		}
		if (!possibilities.isEmpty()) {
			Collections.sort(possibilities);
			return possibilities.get(0);
		}
		throw new Exception("No Bid Determined");
	}

}
