/* ANTIROOT CONFIDENTIAL - 21 Mar. 2010
 THIS WAS MADE FOR CALCULATING PDF & CDF OF ON AND OUT-OF-BID CONDITIONS ON AMAZON EC2 SPOT INSTANCES 
 ALL RIGHTS RESERVED? NO, YOU CAN JUST NOTIFY ME (antiroot@gmail.com, sangho.yi@inria.fr)
 AND MODIFY IT FREELY. 
 Usage: ./sim -f data.csv          -t 500
 ./sim -f FILENAME(TRACE)      TASK_LENGTH(MINUTES)

 GOOD LUCK! - Sangho Yi (antiroot@gmail.com, sangho.yi@inria.fr)
 */
package be.ac.ua.broker.allocation.spot.model;

import java.io.File;

import be.ac.ua.broker.input.pricing.EC2Specifications;
import be.ac.ua.broker.input.pricing.InstanceSpecification;
import be.ac.ua.broker.input.pricing.SpotPrice;

/**
 * The DecisionModel simulator was made for calculating PDF (Probability Density
 * Function) and CDF (Cumulative Density Function) of on- and out-of-bid
 * conditions on Amazon EC2 Spot instances.
 * 
 * @author Vermeersch Kurt (Based on Sangho Yi c++ implementation of the spot
 *         model)
 * @date October 2010
 */
public class SpotModel {

	/**
	 * Execute the spot model simulation for the given instance and return the
	 * appropriate bid.
	 * 
	 * @param spec
	 *            the instance to do the simulation for
	 * @param taskLength
	 *            the length of the job to simulate
	 * @param hoursAvailable
	 *            the number of hours the instance to run the task on is
	 *            available
	 * @return the appropriate bid to use in our broker application
	 * @throws Exception
	 */
	public SpotPrice executeSimulation(InstanceSpecification spec,
			int taskLength, int hoursAvailable) throws Exception {
		Simulator sim = new Simulator();
		if (SpotModelOptions.PRINTOUTPUT) {
			System.out.println("Simulating with " + taskLength
					+ " task length. \n");
		}
		String region = EC2Specifications.getRegionMapping().get(
				spec.getRegion());
		String instance = EC2Specifications.getInstanceTypeMapping().get(
				spec.getInstance());
		String os = EC2Specifications.getOSMapping().get(spec.getOS());
		String instanceName = region + "." + os + "." + instance;
		String filename = SpotModelOptions.INPUT_FOLDER + os + "/" + region
				+ "/" + instanceName + ".csv";
		File file1 = new File(SpotModelOptions.OUTPUT_FOLDER + instanceName
				+ "/results.csv");
		File file2 = new File(SpotModelOptions.OUTPUT_FOLDER + instanceName
				+ "/result_" + taskLength * 60 + "minutes");
		if (!(file1.exists() && file2.exists())) {
			sim.simulate(filename, instanceName, taskLength * 60);
			sim = null;
		}
		OutputReader reader = new OutputReader();
		double bid = reader.getBid(SpotModelOptions.OUTPUT_FOLDER
				+ instanceName + "/results.csv", instanceName, taskLength,
				hoursAvailable, SpotModelOptions.CHECKPOINTING_SCHEME,
				SpotModelOptions.CONFIDENCE_LEVEL);
		return new SpotPrice(bid);
	}

}
