package be.ac.ua.broker.allocation.spot.model;

/**
 * Constants used by the application, this can be extracted to an XML input file
 * in the future. These constants specify the model that will be simulated by
 * the application. Note that the time of a checkpoint, its overhead, the
 * waiting and the recovery times are fixed here.
 * 
 * @author Vermeersch Kurt (Based on Sangho Yi c++ implementation of the spot
 *         model)
 * @date October 2010
 */
public class SpotModelOptions {

	/** Maximum number of records to process e.g. 14400 minutes = 10 days */
	public final static int MAX_RECORD = 60000;
	/** Maximum granularity of a bid (default: 2000 = 0.001 ~ 2.000) */
	public final static int MAX_GRAN_BID = 2000;
	/** Maximum number of simulations (default: 1000 different starting time) */
	public final static int MAX_SIMU_RECORD = 500;
	/** Interval of a simulation in minutes (default: 60) */
	public final static int INTERVAL_SIMU = 60;

	/** Number of available checkpointing schemes */
	public final static int MAX_CHECKPOINT = 2;
	/** Optimal checkpointing */
	public final static int OPT_CKPT = 0;
	/** Hourly checkpointing */
	public final static int HR_CKPT = 1;

	/** Checkpointing overhead time in minutes (default = 3 seconds) */
	public final static double TIME_CHKOVERHEAD = 0.05;
	/** Checkpointing time in minutes (default = 5) */
	public final static int TIME_CHECKPOINT = 5;
	/** Waiting time in minutes (default = 0) */
	public final static int TIME_WAITING = 0;
	/** Recovery time in minutes (default = 10) */
	public final static int TIME_RECOVERY = 10;

	/** Maximum availability ratio (AR=AT/ET) (default: 100 = 0.01 ~ 1.00 ratio) */
	public final static int MAX_DIST_AR = 100;
	/** Maximum utilization ratio (UR=T/ET) (default: 100 = 0.01 ~ 1.00 ratio) */
	public final static int MAX_DIST_UR = 100;
	/** Maximum execution time (default: 1000 = 60 mins = 1 hour */
	public final static int MAX_DIST_EX = 1000;
	/** Each field of the distribution graph represents 60 minutes */
	public final static int INTERVAL_EX = 60;
	/** Maximum gross workload (default: 1000 = 1 mins ~ 1,000 mins) */
	public final static int MAX_DIST_GW = 1000;
	/** Each field of the distribution graph has 1 minute */
	public final static int INTERVAL_GW = 1;
	/** Maximum total cost (default: 1000 = 0.01 USD ~ 10 USD) */
	public final static int MAX_DIST_TC = 1000;
	/** Each field of distribution graph has 0.01 USD */
	public final static double INTERVAL_TC = 0.01;

	/** Task length (for W_inst, workload per instance) */
	public final static int CENTRAL_W = 164;
	/** Interval to differentiate task length with */
	public final static int INTERVAL_W = 10;
	/** Maximum differentiation made from original task length (CENTRAL_W) */
	public final static int RANGE_W = 60;
	
	/** Input folder where the spot price history can be found */
	public static final String INPUT_FOLDER = "input/pricing/spot/";
	/** Output folder where the results will be stored */
	public static final String OUTPUT_FOLDER = "output/spotmodel/";
	/** Checkpointing scheme to use when determining the appropriate bid for the broker */
	public static final String CHECKPOINTING_SCHEME="H";
	/** Confidence level to use when determining the appropriate bid for the broker */
	public static final Double CONFIDENCE_LEVEL=0.99;
	/** Whether or not to print debug output */
	public static boolean PRINTOUTPUT=true; 

}
