package be.ac.ua.broker.allocation.spot.model;

/**
 * The State class represents a certain state of a simulation. It contains the
 * source record, parameter, the corresponding task and an array of checkpoints.
 * 
 * @author Vermeersch Kurt (Based on Sangho Yi c++ implementation of the spot
 *         model)
 * @date October 2010
 */
public class State {

	/** The source record */
	private SrcRecord r;

	/** The parameter containing certain time values */
	private Parameter p;

	/** The task that is being simulated */
	private Task a;

	/** Checkpoints containing the data of the different checkpointing schemes */
	private Checkpoint c[];

	/**
	 * Constructor for State
	 * 
	 * @param rec
	 *            the source record
	 * @param par
	 *            the parameter containing certain time values
	 * @param task
	 *            the task that is being simulated
	 * @param ckps
	 *            the data of the checkpointing schemes that are being simulated
	 */
	public State(SrcRecord rec, Parameter par, Task task, Checkpoint ckps[]) {
		r = rec;
		p = par;
		a = task;
		c = ckps;
	}

	/**
	 * @return the source record corresponding to the state
	 */
	public SrcRecord getSourceRecord() {
		return r;
	}

	/**
	 * @return the parameter containing certain time values
	 */
	public Parameter getParameter() {
		return p;
	}

	/**
	 * @return the task that is being simulated
	 */
	public Task getTask() {
		return a;
	}

	/**
	 * Getter for the checkpoint of the specified checkpointing scheme
	 * 
	 * @param scheme
	 *            the checkpointing scheme to get the data for
	 * @return the requested checkpoint
	 */
	public Checkpoint getCheckpoint(final int scheme) {
		if (scheme >= c.length) {
			throw new IndexOutOfBoundsException(
					"Nonexisting checkpointing scheme provided to State.getC() ["
							+ scheme + "]");
		}
		return c[scheme];
	}

}
