package be.ac.ua.broker.evaluation;

import java.util.Date;

import be.ac.ua.broker.input.pricing.EC2Constants;
import be.ac.ua.broker.utils.DateUtility;

/**
 * This class is used to represent the different options/constants used during
 * the benchmarking of the broker. Note that these should be extracted to an
 * input XML file.
 * 
 * @author Vermeersch Kurt
 * @date May 2011
 */
public class BenchmarkOptions {

	/**
	 * The probability for a randomly generated task to be allowed to run on
	 * spot instances.
	 */
	public static Double PROBABILITY_SPOT_ALLOWED_TASK = 0.5;

	/**
	 * The probability for a randomly generated task to have a deadline that
	 * falls within the last week of the scheduling period, this causes the
	 * results to possibly use reserved instances since these only become
	 * valuable when a certain utilization ratio across the whole scheduling
	 * period is reached.
	 */
	public static Double PROBABILITY_LATE_DEADLINE_TASK = 0.5;

	/**
	 * Whether a graphical representation of the schedule created by every run
	 * of the broker has to be shown.
	 */
	public static Boolean USE_GUI = false;

	/**
	 * Whether debug output/useful information has to be outputted.
	 */
	public static Boolean USE_SYSOUT = true;

	/**
	 * Location where the tasks of the first workload model are stored.
	 */
	public static String FOLDER_WM1 = "input/benchmark/tasks/wm1/";

	/**
	 * Location where the tasks of the second workload model are stored.
	 */
	public static String FOLDER_WM2 = "input/benchmark/tasks/wm2/";

	/**
	 * Start date of the scheduling period used by the broker benchmark, the
	 * scheduling period upper boundary is one year further in time.
	 */
	public static Date startDate = DateUtility.toDate("2010-04-04 00:00");

	/**
	 * Location where the output of the broker for workload model one tasks is
	 * stored.
	 */
	public static String OUTPUT_FOLDER_WM1 = "output/benchmark/wm1/";

	/**
	 * Location where the output of the broker for workload model two tasks is
	 * stored.
	 */
	public static String OUTPUT_FOLDER_WM2 = "output/benchmark/wm2/";

	/**
	 * Input brokering phase name tag to use in output files.
	 */
	public static String PHASE_INPUT = "input";

	/**
	 * Scheduling brokering phase name tag to use in output files.
	 */
	public static String PHASE_SCHEDULING = "scheduling";

	/**
	 * Allocation brokering phase name tag to use in output files.
	 */
	public static String PHASE_ALLOCATION = "allocation";

	/**
	 * Output brokering phase name tag to use in output files.
	 */
	public static String PHASE_OUTPUT = "output";

	/**
	 * Whether the benchmark is run using the first workload model.
	 */
	public static boolean USE_WLM1 = false;

	/**
	 * Whether an alternative benchmark format is being used such that instead
	 * of starting for a certain instance specification with a workload
	 * containing one task and running the broker for every number of tasks once
	 * until the MAX_NUMBER_OF_TASKS is reached by increasing with
	 * NUMBER_OF_TASKS_PER_RUN every time, we now run the benchmark
	 * MAX_NUMBER_OF_TASKS times for every instance type specification every
	 * time using exactly NUMBER_OF_TASKS_PER_RUN tasks. So, we're no longer
	 * investigating what happens to a workload by adding task by task to the
	 * exisiting tasks, instead a random workload of a certain size is generated
	 * every run of the broker.
	 */
	public static boolean BENCH_ALTER = false;

	/**
	 * For the default benchmark behavior this is the maximum number of tasks a
	 * workload contains, for the altered version this is the number of times
	 * the broker is run for every instance specification and option combination
	 * possible.
	 */
	public static Integer MAX_NUMBER_OF_TASKS = 10;

	/**
	 * For the default benchmark behavior this is the number of tasks that are
	 * added to the workload every time the the broker is run for an instance
	 * specification and option combination. For the altered version this is the
	 * fixed number of tasks the workload consists of during a run of the
	 * broker.
	 */
	public static Integer NUMBER_OF_TASKS_PER_RUN = 1;

	/**
	 * The geographical region that is being benchmarked.
	 */
	public static String BENCHMARKING_REGION = EC2Constants.USEAST;

}
