package be.ac.ua.broker.input.pricing;

import java.util.Date;

import be.ac.ua.broker.utils.DateUtility;

/**
 * This class represents a filter that makes sure only the price data of dates
 * in a given period is analyzed.
 * 
 * @author Vermeersch Kurt
 * @date October 2010
 */
public class DateFilter implements CSVFilterInterface {

	/**
	 * Begin date of the Cloudexchange.org spot price history that has to be
	 * analyzed
	 */
	private Date startDate;

	/**
	 * End date of the Cloudexchange.org spot price history that has to be
	 * analyzed
	 */
	private Date endDate;

	/**
	 * Constructor for DateFilter using string representations of the start and
	 * end time
	 * 
	 * @param start
	 *            begin date of the period to analyze the data for
	 * @param end
	 *            end date of the period to analyze the data for
	 */
	public DateFilter(String start, String end) {
		startDate = DateUtility.toDate(start);
		endDate = DateUtility.toDate(end);
	}

	/**
	 * Constructor for DateFilter
	 * 
	 * @param start
	 *            begin date of the period to analyze the data for
	 * @param end
	 *            end date of the period to analyze the data for
	 */
	public DateFilter(Date start, Date end) {
		startDate = start;
		endDate = end;
	}

	@Override
	public boolean keepValue(String val) {
		Date check = DateUtility.toDate(val);
		if (check.equals(startDate) || check.equals(endDate)) {
			return true;
		}
		// If the given date (originating from an input CSV file) lies between
		// the given start and end date the corresponding data should be
		// analyzed so we return true here
		if (check.after(startDate) && check.before(endDate)) {
			return true;
		}
		return false;
	}

	@Override
	public int getColumn() {
		// The column in the input CSV file where the date can be found
		return 0;
	}

	/**
	 * @return the end date of the date filter
	 */
	public Date getEndDate() {
		return endDate;
	}

	/**
	 * @return the start date of the date filter
	 */
	public Date getStartDate() {
		return startDate;
	}

}
