package be.ac.ua.broker.input.pricing;

import be.ac.ua.broker.utils.InputVerifier;
import be.ac.ua.broker.utils.InvalidInputException;

/**
 * This class represents the specification of a certain EC2 instance, it is
 * specified by the instance type, the geographical region and the operating
 * system bneing used.
 * 
 * @author Vermeersch Kurt
 * @date May 2011
 */
public class InstanceSpecification {

	/**
	 * The instance type of the instance specification
	 */
	private String fInstance;

	/**
	 * The geographical region of the instance specification
	 */
	private String fRegion;

	/**
	 * The operating system of the instance specification
	 */
	private String fOS;

	/**
	 * Constructor for InstanceSpecification
	 * 
	 * @param instance
	 *            the instance type of the instance specification
	 * @param os
	 *            the operating system of the instance specification
	 * @throws InvalidInputException
	 */
	public InstanceSpecification(final String instance, final String os)
			throws InvalidInputException {
		InputVerifier.instanceExists(instance);
		InputVerifier.osExists(os);
		fInstance = instance;
		fOS = os;
	}

	/**
	 * Constructor for InstanceSpecification
	 * 
	 * @param instance
	 *            the instance type of the instance specification
	 * @param os
	 *            the operating system of the instance specification
	 * @param region
	 *            the geographical region of the instance specification
	 * @throws InvalidInputException
	 */
	public InstanceSpecification(final String instance, final String os, final String region)
			throws InvalidInputException {
		this(instance, os);
		InputVerifier.regionExists(region);
		fRegion = region;
	}

	/**
	 * @return the instance type of the instance specification
	 */
	public String getInstance() {
		return fInstance;
	}

	/**
	 * @return the geographical region of the instance specification
	 */
	public String getRegion() {
		return fRegion;
	}

	/**
	 * @return the operating system of the instance specification
	 */
	public String getOS() {
		return fOS;
	}

	/**
	 * Setter for the geographical region of the instance specification, this
	 * setter is needed when the user did not appoint a task to a region
	 * 
	 * @param region
	 *            the region of the instance specification
	 * @throws InvalidInputException
	 *             exception thrown when the provided region is not supported
	 */
	public void setRegion(String region) throws InvalidInputException {
		InputVerifier.regionExists(region);
		this.fRegion = region;
	}

	/**
	 * @return an identifier
	 */
	public String getIdentifier() {
		return fRegion + ":" + fOS + ":" + fInstance;
	}

}
