package be.ac.ua.broker.input.pricing;

import java.util.Date;

import be.ac.ua.broker.utils.InstanceNotAvailableException;

/**
 * This interface represents an access point to the prices of EC2 for a
 * particular pricing model
 * 
 * @author Vermeersch Kurt
 * @date May 2011
 */
public interface PriceWatch {

	/**
	 * Update the prices that are returned by the PriceWatch implementation,
	 * reread prices from CSV files for example
	 */
	void update();

	/**
	 * @return name of the pricing model this access point was created for
	 */
	String getPricingModel();

	/**
	 * Getter for the price of the given instance using the pricing model
	 * associated with the PriceWatch implementation
	 * 
	 * @param inst
	 *            the instance specification to get the price for
	 * @return the price for the given instance
	 * @throws InstanceNotAvailableException
	 */
	Price getPrice(InstanceSpecification inst)
			throws InstanceNotAvailableException;

	/**
	 * Getter for the price of the given instance at a certain moment in time
	 * using the pricing model associated with the PriceWatch implementation
	 * 
	 * @param inst
	 *            the instance specification to get the price for
	 * @param timestamp
	 *            time to get the price for
	 * @return the price for the given instance at the given moment in time
	 * @throws InstanceNotAvailableException
	 */
	Price getPrice(InstanceSpecification inst, Date timestamp)
			throws InstanceNotAvailableException;

}
