package be.ac.ua.broker.input.pricing;

/**
 * This class represents a reserved price in the broker. It consist of a fixed
 * price together with a hourly price.
 * 
 * @author Vermeersch Kurt
 * @date May 2011
 */
public class ReservedPrice extends Price {

	/**
	 * The fixed price that needs to be paid to use an instance for a one-year
	 * period.
	 */
	private Double fFixed;

	/**
	 * Constructor for ReservedPrice
	 * 
	 * @param hourly
	 *            the hourly price in US dollars
	 * @param fixed
	 *            the fixed price per one-year period in US dollars
	 */
	public ReservedPrice(double hourly, double fixed) {
		super(hourly);
		fFixed = fixed;
	}

	/**
	 * @return the fixed price per one-year period in US dollars
	 */
	public double getFixedPrice() {
		return fFixed;
	}

	@Override
	public void print() {
		super.print();
		System.out.println("Fixed= " + fFixed);
	}

	@Override
	public String getPricingModel() {
		return EC2Constants.RESERVED;
	}

}
