package be.ac.ua.broker.input.tasks;

import java.util.ArrayList;
import java.util.List;

/**
 * This class represents a collection of subTasks.
 * 
 * @author Vermeersch Kurt
 * @date May 2011
 */
public class SubTaskCollection {

	/**
	 * List of subTasks part of the subTaskCollection
	 */
	private List<SubTask> subTasks = new ArrayList<SubTask>();

	/**
	 * Constructor for SubTaskCollection
	 */
	public SubTaskCollection() {
	}

	/**
	 * Constructor for SubTaskCollection
	 * 
	 * @param tasks
	 *            the initial list of subTasks that are part of the collection
	 */
	public SubTaskCollection(List<SubTask> tasks) {
		subTasks = tasks;
	}

	/**
	 * Constructor for SubTaskCollection
	 * 
	 * @param length
	 *            the number of subTasks in the collection
	 * @param spec
	 *            the specification of the original task all the subTasks in the
	 *            collection are a part of
	 */
	public SubTaskCollection(long length, TaskSpecification spec) {
		for (int i = 0; i < length; i++) {
			this.addTaskHour(new SubTask(i, spec));
		}
	}

	/**
	 * Add a subTask to the collection
	 * 
	 * @param sub
	 *            the subTask to add to the collection
	 */
	public void addTaskHour(SubTask sub) {
		subTasks.add(sub);
	}

	/**
	 * Getter for a specific subTask in the collection
	 * 
	 * @param i
	 *            the number of the subTask to get from the collection
	 * @return the requested subTask
	 */
	public SubTask getTask(int i) {
		if (i <= this.getLength()) {
			return subTasks.get(i);
		}
		throw new IndexOutOfBoundsException();
	}

	/**
	 * @return the number of subTasks in the collection
	 */
	public int getLength() {
		return subTasks.size();
	}

	/**
	 * @return the list of subTasks that are part of the collection
	 */
	public List<SubTask> getWorkload() {
		return subTasks;
	}

}
