package be.ac.ua.broker.input.tasks;

import java.util.Date;

import be.ac.ua.broker.utils.InvalidInputException;

/**
 * This class represents a task.
 * 
 * @author Vermeersch Kurt
 * @date May 2011
 */
public class Task {

	/**
	 * The specification of the task.
	 */
	private TaskSpecification specification;

	/**
	 * The workload the task consists of
	 */
	private Workload workload;

	/**
	 * Constructor for Task
	 * 
	 * @param spec
	 *            the specification of the task
	 * @param wl
	 *            the workload the task consists of
	 */
	public Task(TaskSpecification spec, Workload wl) {
		specification = spec;
		workload = wl;
	}

	/**
	 * @return the workload the task consists of
	 */
	public Workload getWorkload() {
		return workload;
	}

	/**
	 * @return the specification of the task
	 */
	public TaskSpecification getTaskSpecification() {
		return specification;
	}

	/**
	 * @return whether a geographical region for the task to run on has been
	 *         assigned by the user
	 */
	public boolean hasRegionAssigned() {
		return (specification.getInstanceSpecification().getRegion() != null);
	}

	/**
	 * Assign the task to a certain geographical region
	 * 
	 * @param region
	 *            the geographical regions to assign the task to
	 * @throws InvalidInputException
	 *             exception thrown when the provided region is not supported by
	 *             the broker according to the InputVerifier
	 */
	public void setRegion(String region) throws InvalidInputException {
		specification.getInstanceSpecification().setRegion(region);
	}

	/**
	 * Set the start time of the scheduling period for the task
	 * 
	 * @param startDate
	 *            the start time of the scheduling period
	 */
	public void setStartDate(Date startDate) {
		specification.setStartDate(startDate);
	}

}
