package be.ac.ua.broker.input.tasks;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import be.ac.ua.broker.utils.DateUtility;

/**
 * This class represents a collection of tasks.
 * 
 * @author Vermeersch Kurt
 * @date May 2011
 */
public class TaskCollection {

	/**
	 * The list of tasks that are part of the collection
	 */
	private List<Task> tasks = new ArrayList<Task>();

	/**
	 * The start time of the scheduling period for the tasks in the collection
	 */
	private Date startDate;

	/**
	 * Constructor for TaskCollection
	 * 
	 * @param start
	 *            the start time of the scheduling period for the tasks in the
	 *            collection
	 */
	public TaskCollection(Date start) {
		startDate = start;
	}

	/**
	 * Add a task to the collection
	 * 
	 * @param task
	 *            the task to add to the collection
	 */
	public void addTask(Task task) {
		if (task != null) {
			task.setStartDate(startDate);
			tasks.add(task);
		}
	}

	/**
	 * @return list of all the tasks that are part of the collection
	 */
	public List<Task> getTasks() {
		return tasks;
	}

	/**
	 * @return the start time of the scheduling period for the tasks in the
	 *         collection
	 */
	public Date getStartDate() {
		return startDate;
	}

	/**
	 * @return the latest deadline of the tasks in the collection
	 */
	public Date getLatestDeadline() {
		Date d = DateUtility.toDate("2000-01-01 00:00");
		for (Task t : tasks) {
			Date deadline = t.getTaskSpecification().getDeadline();
			if (deadline.after(d)) {
				d = deadline;
			}
		}
		return d;
	}

}
