package be.ac.ua.broker.input.tasks;

import java.util.Date;

import be.ac.ua.broker.input.pricing.InstanceSpecification;

/**
 * This class represents the specification of a single task, it consist of a
 * name, description, deadline of the task. Also the information about the
 * instance on which the task has to be run is stored, the start time of the
 * scheduling period for the task and whether the task is allowed to be run on
 * spot instances is specified.
 * 
 * @author Vermeersch Kurt
 * @date May 2011
 */
public class TaskSpecification {

	/**
	 * The name of the task
	 */
	private String name;

	/**
	 * The description of the task
	 */
	private String description;

	/**
	 * The specification of the instance the task has to run on
	 */
	private InstanceSpecification instanceSpecification;

	/**
	 * The deadline of the task
	 */
	private Date deadline;

	/**
	 * The start time of the scheduling period for the task
	 */
	private Date startDate;

	/**
	 * Whether the task is allowed to be run on spot instances
	 */
	private boolean isSpotAllowed;

	/**
	 * Constructor for TaskSpecification
	 * 
	 * @param nm
	 *            the name of the task
	 * @param desc
	 *            the description of the task
	 * @param spec
	 *            the specification of the instance the task has to run on
	 * @param dead
	 *            the deadline of the task
	 * @param spotAllowed
	 *            whether the task is allowed to be run on spot instances
	 */
	public TaskSpecification(String nm, String desc,
			InstanceSpecification spec, Date dead, boolean spotAllowed) {
		name = nm;
		description = desc;
		instanceSpecification = spec;
		deadline = dead;
		isSpotAllowed = spotAllowed;
	}

	/**
	 * @return the name of the task
	 */
	public String getName() {
		return name;
	}

	/**
	 * @return the description of the task
	 */
	public String getDescription() {
		return description;
	}

	/**
	 * @return the specification of the instance the task has to run on
	 */
	public InstanceSpecification getInstanceSpecification() {
		return instanceSpecification;
	}

	/**
	 * @return the deadline of the task
	 */
	public Date getDeadline() {
		return deadline;
	}

	/**
	 * @return whether the task is allowed to be run on spot instances
	 */
	public boolean isSpotAllowed() {
		return isSpotAllowed;
	}

	/**
	 * Setter for the start time of the scheduling period of the task
	 * 
	 * @param start
	 *            the start time of the scheduling period of the task
	 */
	public void setStartDate(Date start) {
		startDate = start;
	}

	/**
	 * @return the start time of the scheduling period for the task
	 */
	public Date getStart() {
		return startDate;
	}

}
