package be.ac.ua.broker.input.tasks;

import java.util.Date;

/**
 * This interface is used to represent the workload associated with a task, the
 * interface is used by the implementation for the two workload models being
 * supported by the broker. It extends the Comparable interface, since the
 * workloads need to be able to be sorted in an earliest deadline first order.
 * 
 * @author Vermeersch Kurt
 * @date May 2011
 */
public interface Workload extends Comparable<Workload> {

	/**
	 * @return the length in hours of the task/workload
	 */
	public int getLength();

	/**
	 * @return the start time of the scheduling period of the associated task
	 */
	public Date getStartDate();

	/**
	 * @return the deadline by which the workload has to be run
	 */
	public Date getDeadline();

	/**
	 * @return the specification of the task to which the workload belongs
	 */
	public TaskSpecification getTaskSpecification();

	/**
	 * Getter for the workload associated with a given task hour of the task
	 * 
	 * @param j
	 *            the task hour to get the load for
	 * @return the load corresponding to the given task hour
	 */
	public int getWorkload(int j);

}
