package be.ac.ua.broker.input.tasks;

import java.util.Date;
import java.util.List;

import be.ac.ua.broker.utils.DateUtility;

/**
 * This class represents a workload of workload model one.
 * 
 * @author Vermeersch Kurt
 * @date May 2011
 */
public class WorkloadWM1 implements Workload {

	/**
	 * The collection of subTasks that belong to the workload
	 */
	private SubTaskCollection subTasks = new SubTaskCollection();

	/**
	 * The specification of the task the workload belongs to
	 */
	private TaskSpecification specification;

	/**
	 * The number of hours between the start of the scheduling period and the deadline of
	 * the associated task
	 */
	private Integer hoursTimeframe = null;

	/**
	 * Constructor for WorkloadWM1
	 * 
	 * @param spec
	 *            specification of the task the workload belongs to
	 * @param coll
	 *            collection of subTasks that belong to the workload
	 */
	public WorkloadWM1(TaskSpecification spec, SubTaskCollection coll) {
		subTasks = coll;
		specification = spec;
	}

	/**
	 * Constructor for WorkloadWM1
	 * 
	 * @param part
	 *            collection of subTasks that belong to the workload
	 * @param hoursTimeFrame
	 *            the number of hours between the start of the scheduling period
	 *            and the deadline of the associated task
	 */
	public WorkloadWM1(List<SubTask> part, int hoursTimeFrame) {
		hoursTimeframe = hoursTimeFrame;
		subTasks = new SubTaskCollection(part);
	}

	/**
	 * @return the collection of subTasks that belong to the workload
	 */
	public SubTaskCollection getTasks() {
		return subTasks;
	}

	/**
	 * @return the number of hours between the start of the scheduling period
	 *         and the deadline of the associated task
	 */
	public int getHoursTimeFrame() {
		if (hoursTimeframe != null) {
			return hoursTimeframe;
		}
		return DateUtility.getNumberOfHoursBetween(specification.getStart(),
				specification.getDeadline());
	}

	@Override
	public int getLength() {
		return subTasks.getLength();
	}

	@Override
	public Date getStartDate() {
		return specification.getStart();
	}

	@Override
	public Date getDeadline() {
		return specification.getDeadline();
	}

	@Override
	public TaskSpecification getTaskSpecification() {
		return specification;
	}

	@Override
	public int getWorkload(int j) {
		return 1;
	}

	@Override
	public int compareTo(Workload wl) {
		if (wl.getDeadline().before(this.getDeadline())) {
			return 1;
		} else if (this.getDeadline().before(wl.getDeadline())) {
			return -1;
		}
		return 0;
	}

}
