package be.ac.ua.broker.input.tasks.specification;

import java.io.FileNotFoundException;
import java.io.IOException;

import be.ac.ua.broker.input.tasks.SubTaskCollection;
import be.ac.ua.broker.input.tasks.TaskSpecification;
import be.ac.ua.broker.input.tasks.WorkloadWM2;

import com.csvreader.CsvReader;

/**
 * This class is used to read a workload of model two from file.
 * 
 * @author Vermeersch Kurt
 * @date May 2011
 */
public class WorkloadReader {

	/**
	 * Read the workload described by the given file, which is the load for the
	 * given task and instance.
	 * 
	 * @param filePath
	 *            the workload file to read
	 * @param fInstance
	 *            instance type the workload has to be read for
	 * @param spec
	 *            the specification of the task the workload belongs to
	 * @return the workload described by the file
	 */
	public WorkloadWM2 getWorkload(String filePath, String fInstance,
			TaskSpecification spec) {
		WorkloadWM2 workload = new WorkloadWM2(spec);
		try {
			CsvReader fReader = new CsvReader(filePath);
			if (fReader != null) {
				fReader.readRecord();
				int cols = fReader.getColumnCount();
				int column = 0;
				for (int i = 0; i < cols; i++) {
					if (fReader.get(i).equalsIgnoreCase(fInstance)) {
						column = i;
						break;
					}
				}
				while (fReader.readRecord()) {
					long length = Math.round(Math.ceil(Double
							.parseDouble(fReader.get(column))));
					SubTaskCollection coll = new SubTaskCollection(length, spec);
					workload.addTaskHour(coll);
				}
				fReader.close();
			}
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
		return workload;
	}

}
