package be.ac.ua.broker.output.gui;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.GraphicsConfiguration;
import java.awt.Toolkit;

import javax.swing.ImageIcon;
import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JPanel;
import javax.swing.border.BevelBorder;

import be.ac.ua.broker.scheduling.workload.SchedulerResultCollection;

/**
 * This class represents the broker GUI. When the render method is called with a
 * schedule created by the broker, it is shown as a Gantt-like chart to the user
 * using the Swing framework.
 * 
 * @author Vermeersch Kurt
 * @date May 2011
 */
public class ScheduleGUI extends JPanel {

	/** Serial Version ID */
	private static final long serialVersionUID = 1L;

	/** Name of the application to shown in the GUI bar */
	public final static String APP_NAME = "EC2 Broker";

	/** Name of the exit command shown in the GUI menu */
	public final static String EXIT_CMD = "Exit";

	/** The menu bar of the GUI */
	public JMenuBar menuBar;

	/**
	 * Constructor for ScheduleGUI
	 */
	public ScheduleGUI() {
		menuBar = new JMenuBar();
		JMenu formatMenu = new JMenu("File");
		formatMenu.setMnemonic('F');
		MenuAction exitAction = new MenuAction(EXIT_CMD, new ImageIcon(
				"icons/exit.gif"));
		JMenuItem item;
		item = formatMenu.add(exitAction);
		item.setMnemonic('Q');
		menuBar.add(formatMenu);
		menuBar.setBorder(new BevelBorder(BevelBorder.RAISED));

	}

	/**
	 * Render method is called when the GUI has to be shown it is passed a
	 * schedulerResultCollection obtained from the broker after the allocation
	 * phase of the process. For this broker result the GUI will show the
	 * schedules in a Gantt-like fashion and present a cost overview as well.
	 * 
	 * @param result
	 *            the broker result to present a graphical representation for
	 */
	public void render(final SchedulerResultCollection result) {
		JFrame frame = new JFrame(APP_NAME);
		frame.setDefaultCloseOperation(JFrame.HIDE_ON_CLOSE);
		frame.setJMenuBar(menuBar);
		frame.getContentPane().add(new ScheduleRegionTabs(result),
				BorderLayout.CENTER);
		GraphicsConfiguration config = frame.getGraphicsConfiguration();
		final int left = Toolkit.getDefaultToolkit().getScreenInsets(config).left;
		final int right = Toolkit.getDefaultToolkit().getScreenInsets(config).right;
		final int top = Toolkit.getDefaultToolkit().getScreenInsets(config).top;
		final int bottom = Toolkit.getDefaultToolkit().getScreenInsets(config).bottom;
		final Dimension screenSize = Toolkit.getDefaultToolkit()
				.getScreenSize();
		final int width = screenSize.width - left - right;
		final int height = screenSize.height - top - bottom;
		frame.setPreferredSize(new Dimension(width, height));
		frame.pack();
		frame.setVisible(true);
	}

}
