package be.ac.ua.broker.output.gui;

import java.awt.geom.Rectangle2D;

import org.jfree.chart.entity.CategoryItemEntity;
import org.jfree.data.gantt.GanttCategoryDataset;

import be.ac.ua.broker.input.tasks.SubTask;

/**
 * This class is used to represent a categoryItem of the Gantt-chart for the
 * schedule, it contains the corresponding subtasks and an altered
 * tooltipgenerator.
 * 
 * @author Vermeersch Kurt
 * @date May 2011
 */
public class SchedulerCategoryItemEntity extends CategoryItemEntity {

	/** Serial Version ID */
	private static final long serialVersionUID = 1L;

	/**
	 * The toolTipGenerator to use when the user hovers over the corresponding
	 * part of the Gantt-chart for the broker schedule.
	 */
	private ToolTipGenerator tooltipgenerator;

	/**
	 * The subtask corresponding to the part of the schedule corresponding to
	 * this categoryItem of the Gantt-like chart that represents a broker
	 * schedule.
	 */
	private SubTask sub;

	/**
	 * Constructor for SchedulerCategoryItemEntity
	 */
	@SuppressWarnings("deprecation")
	public SchedulerCategoryItemEntity(Rectangle2D bar, String tip, String url,
			GanttCategoryDataset dataset, int row, Comparable<?> columnKey,
			int column, SubTask subtask, ToolTipGenerator tooltipGenerator) {
		super(bar, tip, url, dataset, row, columnKey, column);
		tooltipgenerator = tooltipGenerator;
		sub = subtask;
	}

	@Override
	public String getToolTipText() {
		return tooltipgenerator.generateToolTip(sub);
	}

}
