package be.ac.ua.broker.output.gui;

import org.jfree.chart.labels.IntervalCategoryToolTipGenerator;

import be.ac.ua.broker.input.pricing.EC2Constants;
import be.ac.ua.broker.input.pricing.ReservedPrice;
import be.ac.ua.broker.input.tasks.SubTask;
import be.ac.ua.broker.input.tasks.TaskSpecification;
import be.ac.ua.broker.utils.DateUtility;

/**
 * This class is used as tooltipGenerator, it creates a tooltip text that
 * contains all the relevant subTask and task specifications that are valuable
 * for the use, but also the price that corresponds with the associated task
 * hour in the schedule. The tooltip text is generated only when the user hovers
 * over the part of the Gantt-like chart associated with this task, previously
 * they were generated when the chart was generated but this made the GUI very
 * slow.
 * 
 * @author Vermeersch Kurt (based on GanttRenderer.java by JFreeChart)
 * @date May 2011
 */
public class ToolTipGenerator extends IntervalCategoryToolTipGenerator {

	/** Serial Version ID */
	private static final long serialVersionUID = 1L;

	/**
	 * Constructor for ToolTipGenerator
	 */
	public ToolTipGenerator() {
		super();
	}

	/**
	 * Generate a toolTip text for the given subTask.
	 * 
	 * @param subtask
	 *            the subTask to generate a toolTip text for
	 * @return the toolTip text to use for the provided subTask.
	 */
	public String generateToolTip(SubTask subtask) {
		TaskSpecification t = subtask.getSpecification();
		StringBuffer str = new StringBuffer("<html>");
		str.append("name=" + t.getName() + "<br>");
		str.append("start=" + DateUtility.dateToString(subtask.getStartDate())
				+ "<br>");
		str.append("end=" + DateUtility.dateToString(subtask.getEndDate())
				+ "<br>");
		if (subtask.getPrice() != null) {
			str.append("price=" + subtask.getPrice().getHourlyPrice() + "<br>");
			if (subtask.getPrice().getPricingModel()
					.equals(EC2Constants.RESERVED)) {
				ReservedPrice pr = ((ReservedPrice) subtask.getPrice());
				str.append("fixedprice=" + pr.getFixedPrice() + "<br>");
			}
			str.append("type=" + subtask.getPrice().getPricingModel() + "<br>");
		}
		str.append("hour=" + subtask.getTaskHour() + "<br>");
		str.append("description=" + t.getDescription() + "<br>");
		str.append("instance=" + t.getInstanceSpecification().getInstance()
				+ "<br>");
		str.append("region=" + t.getInstanceSpecification().getRegion()
				+ "<br>");
		str.append("os=" + t.getInstanceSpecification().getOS() + "<br>)");
		str.append("deadline=" + DateUtility.dateToString(t.getDeadline())
				+ "<br>");
		str.append("spotallowed=" + t.isSpotAllowed() + "<br>");
		str.append("</html>");
		return str.toString();
	}

}