package be.ac.ua.broker.scheduling.region;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import be.ac.ua.broker.input.pricing.InstanceSpecification;
import be.ac.ua.broker.input.tasks.Workload;

/**
 * This class is used to represent the workload that is appointed to a certain
 * instance in one geographical region by the RegionAllocator.
 * 
 * @author Vermeersch Kurt
 * @date May 2011
 */
public class InstanceWorkloadCollection {

	/**
	 * The instance specification the workloads are appointed to be run on
	 */
	private InstanceSpecification instanceSpec;

	/**
	 * The associated list of workloads
	 */
	private List<Workload> workloads = new ArrayList<Workload>();

	/**
	 * The start time of the scheduling period
	 */
	private Date startDate = new Date();

	/**
	 * Constructor for InstanceWorkloadCollection
	 * 
	 * @param spec
	 *            the instance specification of the instance the workloads are
	 *            associated with
	 */
	public InstanceWorkloadCollection(final InstanceSpecification spec) {
		instanceSpec = spec;
	}

	/**
	 * Add a provided workload
	 * 
	 * @param workload
	 *            the workload to add to the instance specification specific
	 *            collection of workloads
	 */
	public void add(Workload workload) {
		if (workload.getStartDate().before(startDate)) {
			startDate = workload.getStartDate();
		}
		workloads.add(workload);
	}

	/**
	 * @return the instance specification of the instance this workload
	 *         collection is associated with
	 */
	public InstanceSpecification getSpecification() {
		return instanceSpec;
	}

	/**
	 * @return list of workloads that is associated with the corresponding
	 *         instance of the provided instance specification
	 */
	public List<Workload> getWorkload() {
		return workloads;
	}

	/**
	 * @return the start time of the scheduling period
	 */
	public Date getStartDate() {
		return startDate;
	}

	/**
	 * Print functionality for the instanceWorkloadCollection
	 */
	public void print() {
		for (Workload wl : workloads) {
			System.out.println("\tWorkload="
					+ wl.getTaskSpecification().getName());
		}
	}

}
