package be.ac.ua.broker.scheduling.workload;

import java.util.List;

import be.ac.ua.broker.input.tasks.Workload;

/**
 * This interface is used to for the implementations of the different scheduling
 * options, the optimizer is presented a number of workloads associated with a
 * certain workload model and instance specification. The workloads can be added
 * using the add method, afterwards the determineOptimal method is called, which
 * will schedule the workloads across a number of needed instances in a way that
 * tries to minimize the total cost price of running the load on EC2.
 * 
 * @author Vermeersch Kurt
 * @date May 2011
 */
public interface Optimizer<W extends Workload> {

	/**
	 * Add the provided workload to the scheduling optimizer.
	 * 
	 * @param wl
	 *            the workload to add.
	 */
	public void add(W wl);

	/**
	 * @return a list of scheduledTaskCollections, one of these represents the
	 *         schedule containing subTasks for a single instance. This
	 *         schedules are made in a way that tries to minimize the total cost
	 *         of running the workload on EC2.
	 */
	public List<ScheduledTaskCollection> determineOptimal();

}
