package be.ac.ua.broker.scheduling.workload;

/**
 * This class is used to represent the different options used during the
 * scheduling phase of the broker: basic, optimized or spot-optimized. 
 * - Basic scheduling is the naive method in which every task is scheduled 
 * on a separate resource. The task hours are scheduled consecutively starting 
 * at the beginning of the schedule. 
 * - Optimized scheduling is the method in which the
 * task hours are distributed as equally as possible over time, in order to get
 * resources that are loaded as much of the time as possible. 
 * - Spot-Optimized scheduling is an alteration of the optimized algorithm, that 
 * ensures that the least loaded resources contain as much spot-enabled task 
 * parts as possible.
 * 
 * @author Vermeersch Kurt
 * @date May 2011
 */
public interface SchedulerOptions {
	
	/** Scheduling Phase Option: Basic. */
	public static final String BASIC = "basic";
	
	/** Scheduling Phase Option: Optimized. */
	public static final String OPTIMIZED = "optimized";
	
	/** Scheduling Phase Option: Spot-Optimized. */
	public static final String SPOTOPTIMIZED = "spot";

}
