package be.ac.ua.broker.scheduling.workload;

import java.util.ArrayList;
import java.util.List;

import be.ac.ua.broker.input.pricing.InstanceSpecification;

/**
 * This class is used to represent the resulting schedule of the broker created
 * during the scheduling phase of the broker process. The optimizer returns a
 * schedulerResult, since it represents a schedule associated with a singel
 * instance specification.
 * 
 * @author Vermeersch Kurt
 * @date May 2011
 */
public class SchedulerResult {

	/**
	 * The instance specification of the instance the schedule is created for
	 */
	private InstanceSpecification specification;

	/**
	 * List of ScheduledTaskCollections, which are representations of schedules
	 * of subTasks on separate instances of the specified type
	 */
	private List<ScheduledTaskCollection> list = new ArrayList<ScheduledTaskCollection>();

	/**
	 * Constructor for SchedulerResults
	 * 
	 * @param spec
	 *            the specification of the instance this schedule is created for
	 */
	public SchedulerResult(InstanceSpecification spec) {
		specification = spec;
	}

	/**
	 * @return the specification of the instance the schedulerResult is created
	 *         for
	 */
	public InstanceSpecification getInstanceSpecification() {
		return specification;
	}

	/**
	 * Add a schedule of subTasks on a single instance to the schedule for the
	 * given instance specification in the region being processed
	 * 
	 * @param scheduledTasks
	 *            the schedule to add to the result
	 */
	public void addScheduledTaskCollection(
			ScheduledTaskCollection scheduledTasks) {
		list.add(scheduledTasks);
	}

	/**
	 * @return the list of schedules of separate EC2 instances
	 */
	public List<ScheduledTaskCollection> getScheduledTaskCollections() {
		return list;
	}

	/**
	 * @return the geographical region this schedule is associated with
	 */
	public String getRegion() {
		return specification.getRegion();
	}

}
