package be.ac.ua.broker.utils;

import be.ac.ua.broker.input.pricing.InstanceSpecification;

/**
 * This class represents the exception that is thrown when the user provides
 * input that uses an instance type, regions or operating system that is not
 * recognized by our application.
 * 
 * @author Vermeersch Kurt
 * @date May 2011
 */
public class InstanceNotAvailableException extends Exception {

	/** Serial Version ID */
	private static final long serialVersionUID = 1L;

	/** Provided instance type by user input */
	private String fInstance;

	/** Provided geographical region by user input */
	private String fRegion;

	/** Provided operating system by user input */
	private String fOS;

	/**
	 * Constructor for InstanceNotAvailableException
	 * 
	 * @param instance
	 *            input instance type
	 * @param region
	 *            input geographical region
	 * @param os
	 *            input operating system
	 */
	public InstanceNotAvailableException(final String instance,
			final String region, final String os) {
		fInstance = instance;
		fRegion = region;
		fOS = os;
	}

	/**
	 * Constructor for InstanceNotAvailableException
	 * 
	 * @param instance
	 *            input instance type
	 */
	public InstanceNotAvailableException(final String instance) {
		fInstance = instance;
	}

	/**
	 * Constructor for InstanceNotAvailableException
	 * 
	 * @param inst
	 *            specification of the instance that is not available
	 */
	public InstanceNotAvailableException(final InstanceSpecification inst) {
		fInstance = inst.getInstance();
		fRegion = inst.getRegion();
		fOS = inst.getOS();
	}

	/**
	 * @return the provided instance type by user input
	 */
	public String getInstance() {
		return fInstance;
	}

	/**
	 * @return the provided geographical region by user input
	 */
	public String getRegion() {
		return fRegion;
	}

	/**
	 * @return the provided operating system by user input
	 */
	public String getOS() {
		return fOS;
	}

}
