package be.ac.ua.broker.utils;

import java.awt.Color;
import java.util.Random;

/**
 * This class contains some random variable generation utilities needed by the
 * broker application. It provides static methods to generate a random integer
 * within a range of numbers and the generation of a random boolean value.
 * 
 * @author Vermeersch Kurt
 * @date May 2011
 */
public class RandomGenerator {

	/** The Random instance used to generate random variables. */
	private static Random randomGenerator = new Random();

	/**
	 * Generate a random Integer that lies between the given rangeBegin and the
	 * rangeEnd value.
	 * 
	 * @param rangeBegin
	 *            lower boundary for the random Integer to return
	 * @param rangeEnd
	 *            upper boundary for the random Integer to return
	 * @return the randomly generated Integer
	 */
	public static int generateRandomInt(final int rangeBegin, final int rangeEnd) {
		if (rangeEnd >= rangeBegin) {
			int range = rangeEnd - rangeBegin + 1;
			int randomInt = randomGenerator.nextInt(range);
			return rangeBegin + randomInt;
		}
		return 0;
	}

	/**
	 * @return the randomly generated Boolean
	 */
	public static boolean generateRandomBoolean() {
		return randomGenerator.nextBoolean();
	}
	
	/**
	 * @return a randomly generated Color
	 */
	public static Color generateRandomColor() {
		return (new Color(randomGenerator.nextInt(256), randomGenerator.nextInt(256),
				randomGenerator.nextInt(256)));
	}

}
